Learn R Programming

pubchem.bio (version 1.0.5)

build.element.count: build.element.count

Description

takes as input an pubchem.bio data.table (generally produced by 'build.pubchem.bio' or 'build.taxon.metabolome') and removes inorganic compounds (those without any carbon).

Usage

build.element.count(
  pc.directory = NULL,
  pubchem.bio.object = NULL,
  remove.homonuclear.molecules = TRUE,
  remove.inorganics = TRUE
)

Value

a data.table, same as input, except inorganics will have been removed.

Arguments

pc.directory

directory from which to load pubchem .Rdata files

pubchem.bio.object

R data.table, generally produced by build.pubchem.bio; preferably, define pc.directory

remove.homonuclear.molecules

logical. default = TRUE. should molecules with one element (or fewer) be removed?

remove.inorganics

logical. default = TRUE. Should inorganic molecules (no carbon) be removed?

Author

Corey Broeckling

Details

utilizes downloaded and properly formatted local pubchem data created by 'build.pubchem.bio' function, removes inorganic compounds. note that for any formula which have charge noted '+' or '-', the charge is removed for tabulation of the element count.