Learn R Programming

pubchem.bio (version 1.0.5)

export.pubchem.bio: export.pubchem.bio

Description

export pubchem.bio pc.bio syle data.table to tab delimited text file for import into other programs. all columns exported.

Usage

export.pubchem.bio(pc.bio.object = NULL, export.file.name = NULL)

Value

nothing - file written to disk.

Arguments

pc.bio.object

input data.table, generated from 'build.pubchem.bio' or 'build.taxon.metabolome' functions

export.file.name

valid file path and name. Extension should be listed as '.tsv'.

Author

Corey Broeckling

Details

takes output from 'build.pubchem.bio' or 'build.taxon.metabolome' functions, reformatting, and exporting to input format suitable for MSFinder.