export pubchem.bio pc.bio syle data.table to tab delimited text file for import into other programs. all columns exported.
export.pubchem.bio(pc.bio.object = NULL, export.file.name = NULL)nothing - file written to disk.
input data.table, generated from 'build.pubchem.bio' or 'build.taxon.metabolome' functions
valid file path and name. Extension should be listed as '.tsv'.
Corey Broeckling
takes output from 'build.pubchem.bio' or 'build.taxon.metabolome' functions, reformatting, and exporting to input format suitable for MSFinder.